@@ -3,47 +3,65 @@
 """Convert SAM templates to CloudFormation templates.
 
 Known limitations: cannot transform CodeUri pointing at local directory.
-
-Usage:
-  sam-translate.py --template-file=sam-template.yaml [--verbose] [--output-template=<o>]
-  sam-translate.py package --template-file=sam-template.yaml --s3-bucket=my-bucket [--verbose] [--output-template=<o>]
-  sam-translate.py deploy --template-file=sam-template.yaml --s3-bucket=my-bucket --capabilities=CAPABILITY_NAMED_IAM --stack-name=my-stack [--verbose] [--output-template=<o>]
-
-Options:
-  --template-file=<i>       Location of SAM template to transform [default: template.yaml].
-  --output-template=<o>     Location to store resulting CloudFormation template [default: transformed-template.json].
-  --s3-bucket=<s>           S3 bucket to use for SAM artifacts when using the `package` command
-  --capabilities=<c>        Capabilities
-  --stack-name=<n>          Unique name for your CloudFormation Stack
-  --verbose                 Enables verbose logging
-
 """
+import argparse
 import json
 import logging
 import os
 import platform
 import subprocess
 import sys
+from functools import reduce
+from pathlib import Path
 
 import boto3
 
-from docopt import docopt  # type: ignore[import]
-from functools import reduce
-
+# To allow this script to be executed from other directories
 my_path = os.path.dirname(os.path.abspath(__file__))
 sys.path.insert(0, my_path + "/..")
 
+from samtranslator.model.exceptions import InvalidDocumentException
 from samtranslator.public.translator import ManagedPolicyLoader
 from samtranslator.translator.transform import transform
 from samtranslator.yaml_helper import yaml_parse
-from samtranslator.model.exceptions import InvalidDocumentException
 
 LOG = logging.getLogger(__name__)
-cli_options = docopt(__doc__)
 iam_client = boto3.client("iam")
-cwd = os.getcwd()
 
-if cli_options.get("--verbose"):
+parser = argparse.ArgumentParser(description=__doc__)
+parser.add_argument("command", nargs="?")
+parser.add_argument(
+    "--template-file",
+    help="Location of SAM template to transform [default: template.yaml].",
+    type=Path,
+    default=Path("template.yaml"),
+)
+parser.add_argument(
+    "--output-template",
+    help="Location to store resulting CloudFormation template [default: transformed-template.json].",
+    type=Path,
+    default=Path("transformed-template.yaml"),
+)
+parser.add_argument(
+    "--s3-bucket",
+    help="S3 bucket to use for SAM artifacts when using the `package` command",
+)
+parser.add_argument(
+    "--capabilities",
+    help="Capabilities",
+)
+parser.add_argument(
+    "--stack-name",
+    help="Unique name for your CloudFormation Stack",
+)
+parser.add_argument(
+    "--verbose",
+    help="Enables verbose logging",
+    action="store_true",
+)
+cli_options = parser.parse_args()
+
+if cli_options.verbose:
     logging.basicConfig(level=logging.DEBUG)
 else:
     logging.basicConfig()
@@ -52,7 +70,7 @@ else:
 def execute_command(command, args):  # type: ignore[no-untyped-def]
     try:
         aws_cmd = "aws" if platform.system().lower() != "windows" else "aws.cmd"
-        command_with_args = [aws_cmd, "cloudformation", command] + list(args)
+        command_with_args = [aws_cmd, "cloudformation", command, *list(args)]
 
         LOG.debug("Executing command: %s", command_with_args)
 
@@ -65,19 +83,10 @@ def execute_command(command, args):  # type: ignore[no-untyped-def]
         sys.exit(e.returncode)
 
 
-def get_input_output_file_paths():  # type: ignore[no-untyped-def]
-    input_file_option = cli_options.get("--template-file")
-    output_file_option = cli_options.get("--output-template")
-    input_file_path = os.path.join(cwd, input_file_option)
-    output_file_path = os.path.join(cwd, output_file_option)
-
-    return input_file_path, output_file_path
-
-
 def package(input_file_path, output_file_path):  # type: ignore[no-untyped-def]
     template_file = input_file_path
     package_output_template_file = input_file_path + "._sam_packaged_.yaml"
-    s3_bucket = cli_options.get("--s3-bucket")
+    s3_bucket = cli_options.s3_bucket
     args = [
         "--template-file",
         template_file,
@@ -112,8 +121,8 @@ def transform_template(input_file_path, output_file_path):  # type: ignore[no-un
 
 
 def deploy(template_file):  # type: ignore[no-untyped-def]
-    capabilities = cli_options.get("--capabilities")
-    stack_name = cli_options.get("--stack-name")
+    capabilities = cli_options.capabilities
+    stack_name = cli_options.stack_name
     args = ["--template-file", template_file, "--capabilities", capabilities, "--stack-name", stack_name]
 
     execute_command("deploy", args)  # type: ignore[no-untyped-call]
@@ -122,12 +131,13 @@ def deploy(template_file):  # type: ignore[no-untyped-def]
 
 
 if __name__ == "__main__":
-    input_file_path, output_file_path = get_input_output_file_paths()  # type: ignore[no-untyped-call]
+    input_file_path = str(cli_options.template_file)
+    output_file_path = str(cli_options.output_template)
 
-    if cli_options.get("package"):
+    if cli_options.command == "package":
         package_output_template_file = package(input_file_path, output_file_path)  # type: ignore[no-untyped-call]
         transform_template(package_output_template_file, output_file_path)  # type: ignore[no-untyped-call]
-    elif cli_options.get("deploy"):
+    elif cli_options.command == "deploy":
         package_output_template_file = package(input_file_path, output_file_path)  # type: ignore[no-untyped-call]
         transform_template(package_output_template_file, output_file_path)  # type: ignore[no-untyped-call]
         deploy(output_file_path)  # type: ignore[no-untyped-call]
