@@ -1,12 +1,10 @@
-from integration.helpers.base_test import BaseTest
-import requests
 from unittest.case import skipIf
 
+from parameterized import parameterized
+
+from integration.config.service_names import REST_API
 from integration.helpers.base_test import BaseTest
 from integration.helpers.resource import current_region_does_not_support
-from integration.config.service_names import REST_API
-from integration.helpers.deployer.utils.retry import retry
-from parameterized import parameterized
 
 ALL_METHODS = "DELETE,GET,HEAD,OPTIONS,PATCH,POST,PUT"
 
