@@ -1,14 +1,14 @@
 """ CloudFormation Resource serialization, deserialization, and validation """
-import re
 import inspect
-from abc import ABC
+import re
+from abc import ABC, ABCMeta, abstractmethod
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
-from abc import ABCMeta
+
 from samtranslator.intrinsics.resolver import IntrinsicsResolver
 from samtranslator.model.exceptions import ExpectedType, InvalidResourceException, InvalidResourcePropertyTypeException
+from samtranslator.model.tags.resource_tagging import get_tag_list
 from samtranslator.model.types import IS_DICT, IS_STR, Validator, any_type, is_type
 from samtranslator.plugins import LifeCycleEvents
-from samtranslator.model.tags.resource_tagging import get_tag_list
 
 
 class PropertyType:
@@ -274,7 +274,7 @@ class Resource(ABC):
         resource_dict.update(self.resource_attributes)
 
         properties_dict = {}
-        for name in self.property_types.keys():
+        for name in self.property_types:
             value = getattr(self, name)
             if value is not None:
                 properties_dict[name] = value
@@ -291,7 +291,7 @@ class Resource(ABC):
         :param value: the value of the attribute to be set
         :raises InvalidResourceException: if an invalid property is provided
         """
-        if name in self._keywords or name in self.property_types.keys():
+        if name in self._keywords or name in self.property_types:
             return super().__setattr__(name, value)
 
         raise InvalidResourceException(
@@ -409,6 +409,7 @@ class ResourceMacro(Resource, metaclass=ABCMeta):
         """
         return {}
 
+    @abstractmethod
     def to_cloudformation(self, **kwargs: Any) -> List[Any]:
         """Returns a list of Resource instances, representing vanilla CloudFormation resources, to which this macro
         expands. The caller should be able to update their template with the expanded resources by calling
@@ -534,7 +535,7 @@ class ResourceTypeResolver:
             for _, resource_class in inspect.getmembers(
                 module,
                 lambda cls: inspect.isclass(cls)
-                and cls.__module__ == module.__name__
+                and cls.__module__ == module.__name__  # noqa: function-uses-loop-variable
                 and hasattr(cls, "resource_type"),
             ):
                 self.resource_types[resource_class.resource_type] = resource_class
@@ -592,3 +593,20 @@ class ResourceResolver:
             raise TypeError("Invalid logical ID '{}'. Expected a string.".format(_input))
 
         return self.resources.get(_input, None)
+
+
+__all__: List[str] = [
+    "IS_DICT",
+    "IS_STR",
+    "Validator",
+    "any_type",
+    "is_type",
+    "PropertyType",
+    "Property",
+    "PassThroughProperty",
+    "Resource",
+    "ResourceMacro",
+    "SamResourceMacro",
+    "ResourceTypeResolver",
+    "ResourceResolver",
+]
