@@ -9,7 +9,7 @@ from samtranslator.model.intrinsics import is_intrinsic_no_value, make_condition
 from samtranslator.utils.py27hash_fix import Py27Dict
 
 
-class BaseEditor(object):
+class BaseEditor:
     # constants:
     _X_APIGW_INTEGRATION = "x-amazon-apigateway-integration"
     _CONDITIONAL_IF = "Fn::If"
@@ -42,7 +42,7 @@ class BaseEditor(object):
                     [InvalidTemplateException(f"Value of {BaseEditor._CONDITIONAL_IF} must be a list.")]
                 )
             contents = if_parameters[1:]
-            contents = [content for content in contents if not is_intrinsic_no_value(content)]
+            return [content for content in contents if not is_intrinsic_no_value(content)]
         return contents
 
     @staticmethod
