@@ -1,15 +1,22 @@
 import copy
+import json
 import re
-from typing import Any, Dict, Optional
+from typing import Any, Callable, Dict, Optional, TypeVar
 
+from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model.apigatewayv2 import ApiGatewayV2Authorizer
-from samtranslator.model.intrinsics import ref, make_conditional, is_intrinsic
 from samtranslator.model.exceptions import InvalidDocumentException, InvalidTemplateException
+from samtranslator.model.intrinsics import is_intrinsic, make_conditional, ref
 from samtranslator.open_api.base_editor import BaseEditor
 from samtranslator.utils.py27hash_fix import Py27Dict, Py27UniStr
 from samtranslator.utils.types import Intrinsicable
-from samtranslator.utils.utils import dict_deep_get, InvalidValueType
-import json
+from samtranslator.utils.utils import InvalidValueType, dict_deep_get
+
+T = TypeVar("T")
+
+
+# Wrap around copy.deepcopy to isolate time cost to deepcopy the doc.
+_deepcopy: Callable[[T], T] = cw_timer(prefix="OpenApiEditor")(copy.deepcopy)
 
 
 class OpenApiEditor(BaseEditor):
@@ -32,6 +39,9 @@ class OpenApiEditor(BaseEditor):
     _DEFAULT_PATH = "$default"
     _DEFAULT_OPENAPI_TITLE = ref("AWS::StackName")
 
+    # Attributes:
+    _doc: Dict[str, Any]
+
     def __init__(self, doc: Optional[Dict[str, Any]]) -> None:
         """
         Initialize the class with a swagger dictionary. This class creates a copy of the Swagger and performs all
@@ -49,7 +59,7 @@ class OpenApiEditor(BaseEditor):
                 ]
             )
 
-        self._doc = copy.deepcopy(doc)
+        self._doc = _deepcopy(doc)
         self.paths = self._doc["paths"]
         try:
             self.security_schemes = dict_deep_get(self._doc, "components.securitySchemes") or Py27Dict()
@@ -103,7 +113,7 @@ class OpenApiEditor(BaseEditor):
 
         return True
 
-    def add_lambda_integration(  # type: ignore[no-untyped-def]
+    def add_lambda_integration(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
         self, path, method, integration_uri, method_auth_config=None, api_auth_config=None, condition=None
     ):
         """
@@ -326,7 +336,6 @@ class OpenApiEditor(BaseEditor):
             authorization_scopes = []
 
         for method_definition in self.iter_on_method_definitions_for_path_at_method(path, method_name):
-
             security_dict = {}  # type: ignore[var-annotated]
             security_dict[authorizer_name] = []
 
@@ -412,7 +421,7 @@ class OpenApiEditor(BaseEditor):
 
         self._doc[self._SERVERS] = servers_configurations
 
-    def add_cors(  # type: ignore[no-untyped-def]
+    def add_cors(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
         self,
         allow_origins,
         allow_headers=None,
@@ -527,7 +536,7 @@ class OpenApiEditor(BaseEditor):
         if self.info:
             self._doc["info"] = self.info
 
-        return copy.deepcopy(self._doc)
+        return _deepcopy(self._doc)
 
     @staticmethod
     def is_valid(data: Any) -> bool:
@@ -538,11 +547,8 @@ class OpenApiEditor(BaseEditor):
         :return: True, if data is valid OpenApi
         """
 
-        if bool(data) and isinstance(data, dict) and isinstance(data.get("paths"), dict):
-            if bool(data.get("openapi")):
-                return OpenApiEditor.safe_compare_regex_with_string(
-                    OpenApiEditor._OPENAPI_VERSION_3_REGEX, data["openapi"]
-                )
+        if bool(data) and isinstance(data, dict) and isinstance(data.get("paths"), dict) and bool(data.get("openapi")):
+            return OpenApiEditor.safe_compare_regex_with_string(OpenApiEditor._OPENAPI_VERSION_3_REGEX, data["openapi"])
         return False
 
     @staticmethod
