@@ -1,21 +1,19 @@
 import copy
-
 from abc import ABCMeta, abstractmethod
 from typing import Any, Dict, Generic, Optional, Tuple, Type, TypeVar, Union
 
 from samtranslator.metrics.method_decorator import cw_timer
-from samtranslator.model.intrinsics import make_combined_condition
 from samtranslator.model.eventsources.push import Api
+from samtranslator.model.intrinsics import MIN_NUM_CONDITIONS_TO_COMBINE, make_combined_condition
 from samtranslator.open_api.open_api import OpenApiEditor
+from samtranslator.public.exceptions import InvalidDocumentException, InvalidEventException, InvalidResourceException
 from samtranslator.public.plugins import BasePlugin
-from samtranslator.public.exceptions import InvalidDocumentException, InvalidResourceException, InvalidEventException
 from samtranslator.public.sdk.resource import SamResource, SamResourceType
 from samtranslator.public.sdk.template import SamTemplate
 from samtranslator.swagger.swagger import SwaggerEditor
 from samtranslator.utils.py27hash_fix import Py27Dict
 from samtranslator.validator.value_validator import sam_expect
 
-
 T = TypeVar("T", bound=Union[Type[OpenApiEditor], Type[SwaggerEditor]])
 
 
@@ -64,7 +62,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         self.api_update_replace_policies: Dict[str, Any] = {}
 
     @abstractmethod
-    def _process_api_events(
+    def _process_api_events(  # noqa: too-many-arguments
         self,
         function: SamResource,
         api_events: Dict[str, Dict[str, Any]],
@@ -121,7 +119,6 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         for logicalId, resource in template.iterate(
             {SamResourceType.Function.value, SamResourceType.StateMachine.value}
         ):
-
             api_events = self._get_api_events(resource)  # type: ignore[no-untyped-call]
             condition = resource.condition
             deletion_policy = resource.deletion_policy
@@ -181,7 +178,6 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
 
         api_events = Py27Dict()
         for event_id, event in resource.properties["Events"].items():
-
             if event and isinstance(event, dict) and event.get("Type") == self.API_EVENT_TYPE:
                 api_events[event_id] = event
 
@@ -208,7 +204,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         is_referencing_http_from_api_event = (
             not template.get(api_id)
             or template.get(api_id).type == "AWS::Serverless::HttpApi"
-            and not template.get(api_id).type == self.SERVERLESS_API_RESOURCE_TYPE
+            and template.get(api_id).type != self.SERVERLESS_API_RESOURCE_TYPE
         )
 
         # RestApiId is not pointing to a valid  API resource
@@ -371,7 +367,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
                                            top-level condition.
         """
         # defensive precondition check
-        if not conditions_to_combine or len(conditions_to_combine) < 2:
+        if not conditions_to_combine or len(conditions_to_combine) < MIN_NUM_CONDITIONS_TO_COMBINE:
             raise ValueError("conditions_to_combine must have at least 2 conditions")
 
         template_conditions = template_dict.setdefault("Conditions", {})
@@ -464,7 +460,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
             sam_expect(method, event_id, "Method", is_sam_event=True).to_be_a_string(),
         )
 
-    def _update_resource_attributes_from_api_event(
+    def _update_resource_attributes_from_api_event(  # noqa: too-many-arguments
         self,
         api_id: str,
         path: str,
