@@ -1,19 +1,21 @@
-import boto3
+import copy
 import json
-from botocore.config import Config
-from botocore.exceptions import ClientError, EndpointConnectionError
 import logging
 from time import sleep
-import copy
+from typing import Any, Dict, Tuple
 
+import boto3
+from botocore.config import Config
+from botocore.exceptions import ClientError, EndpointConnectionError
+
+from samtranslator.intrinsics.actions import FindInMapAction
+from samtranslator.intrinsics.resolver import IntrinsicsResolver
 from samtranslator.metrics.method_decorator import cw_timer
 from samtranslator.model.exceptions import InvalidResourceException
 from samtranslator.plugins import BasePlugin
 from samtranslator.plugins.exceptions import InvalidPluginException
 from samtranslator.public.sdk.resource import SamResourceType
 from samtranslator.public.sdk.template import SamTemplate
-from samtranslator.intrinsics.resolver import IntrinsicsResolver
-from samtranslator.intrinsics.actions import FindInMapAction
 from samtranslator.region_configuration import RegionConfiguration
 from samtranslator.utils.constants import BOTO3_CONNECT_TIMEOUT
 from samtranslator.validator.value_validator import sam_expect
@@ -57,7 +59,7 @@ class ServerlessAppPlugin(BasePlugin):
         :param bool wait_for_template_active_status: Flag to wait for all templates to become active
         :param bool validate_only: Flag to only validate application access (uses get_application API instead)
         """
-        super(ServerlessAppPlugin, self).__init__(ServerlessAppPlugin.__name__)
+        super().__init__()
         if parameters is None:
             parameters = {}
         self._applications = {}
@@ -71,7 +73,12 @@ class ServerlessAppPlugin(BasePlugin):
         # make sure the flag combination makes sense
         if self._validate_only is True and self._wait_for_template_active_status is True:
             message = "Cannot set both validate_only and wait_for_template_active_status flags to True."
-            raise InvalidPluginException(ServerlessAppPlugin.__name__, message)  # type: ignore[no-untyped-call]
+            raise InvalidPluginException(ServerlessAppPlugin.__name__, message)
+
+    @staticmethod
+    def _make_app_key(app_id: Any, semver: Any) -> Tuple[str, str]:
+        """Generate a key that is always hashable."""
+        return json.dumps(app_id, default=str), json.dumps(semver, default=str)
 
     @cw_timer(prefix=PLUGIN_METRICS_PREFIX)
     def on_before_transform_template(self, template_dict):  # type: ignore[no-untyped-def]
@@ -83,16 +90,14 @@ class ServerlessAppPlugin(BasePlugin):
         This verifies that the user has access to all specified applications.
 
         :param dict template_dict: Dictionary of the SAM template
-        :return: Nothing
         """
         template = SamTemplate(template_dict)
         intrinsic_resolvers = self._get_intrinsic_resolvers(template_dict.get("Mappings", {}))  # type: ignore[no-untyped-call]
 
         service_call = None
-        if self._validate_only:
-            service_call = self._handle_get_application_request
-        else:
-            service_call = self._handle_create_cfn_template_request
+        service_call = (
+            self._handle_get_application_request if self._validate_only else self._handle_create_cfn_template_request
+        )
         for logical_id, app in template.iterate({SamResourceType.Application.value}):
             if not self._can_process_application(app):  # type: ignore[no-untyped-call]
                 # Handle these cases in the on_before_transform_resource event
@@ -106,15 +111,18 @@ class ServerlessAppPlugin(BasePlugin):
                 app.properties[self.LOCATION_KEY], self.SEMANTIC_VERSION_KEY, intrinsic_resolvers
             )
 
+            key = self._make_app_key(app_id, semver)
+
             if isinstance(app_id, dict) or isinstance(semver, dict):
-                key = (json.dumps(app_id), json.dumps(semver))
                 self._applications[key] = False
                 continue
 
-            key = (app_id, semver)
-
             if key not in self._applications:
                 try:
+                    # Examine the type of ApplicationId and SemanticVersion
+                    # before calling SAR API.
+                    sam_expect(app_id, logical_id, "Location.ApplicationId").to_be_a_string()
+                    sam_expect(semver, logical_id, "Location.SemanticVersion").to_be_a_string()
                     if not RegionConfiguration.is_service_supported("serverlessrepo"):  # type: ignore[no-untyped-call]
                         raise InvalidResourceException(
                             logical_id, "Serverless Application Repository is not available in this region."
@@ -138,7 +146,7 @@ class ServerlessAppPlugin(BasePlugin):
                 error_code = e.response["Error"]["Code"]
                 if error_code == "TooManyRequestsException":
                     LOG.debug("SAR call timed out for application id {}".format(app_id))
-                    sleep_time = self._get_sleep_time_sec()  # type: ignore[no-untyped-call]
+                    sleep_time = self._get_sleep_time_sec()
                     sleep(sleep_time)
                     self._total_wait_time += sleep_time
                     continue
@@ -155,8 +163,8 @@ class ServerlessAppPlugin(BasePlugin):
 
     def _get_intrinsic_resolvers(self, mappings):  # type: ignore[no-untyped-def]
         return [
-            IntrinsicsResolver(self._parameters),  # type: ignore[no-untyped-call]
-            IntrinsicsResolver(mappings, {FindInMapAction.intrinsic_name: FindInMapAction()}),  # type: ignore[no-untyped-call, no-untyped-call]
+            IntrinsicsResolver(self._parameters),
+            IntrinsicsResolver(mappings, {FindInMapAction.intrinsic_name: FindInMapAction()}),
         ]
 
     def _resolve_location_value(self, value, intrinsic_resolvers):  # type: ignore[no-untyped-def]
@@ -245,7 +253,6 @@ class ServerlessAppPlugin(BasePlugin):
         :param string logical_id: Logical ID of the resource being processed
         :param string resource_type: Type of the resource being processed
         :param dict resource_properties: Properties of the resource
-        :return: Nothing
         """
 
         if not self._resource_is_supported(resource_type):  # type: ignore[no-untyped-call]
@@ -286,7 +293,7 @@ class ServerlessAppPlugin(BasePlugin):
                 "and Ref intrinsic functions are supported.",
             )
 
-        key = (app_id, semver)
+        key = self._make_app_key(app_id, semver)
 
         # Throw any resource exceptions saved from the before_transform_template event
         if isinstance(self._applications[key], InvalidResourceException):
@@ -317,7 +324,6 @@ class ServerlessAppPlugin(BasePlugin):
         Go through all the stored applications and make sure they're all ACTIVE.
 
         :param dict template: Dictionary of the SAM template
-        :return: Nothing
         """
         if not self._wait_for_template_active_status or self._validate_only:
             return
@@ -340,7 +346,7 @@ class ServerlessAppPlugin(BasePlugin):
                         break  # We were throttled by SAR, break out to a sleep
                     raise e
 
-                if self._is_template_active(response, application_id, template_id):  # type: ignore[no-untyped-call]
+                if self._is_template_active(response, application_id, template_id):
                     self._in_progress_templates.remove((application_id, template_id))
                 else:
                     idx += 1  # check next template
@@ -352,7 +358,7 @@ class ServerlessAppPlugin(BasePlugin):
                 break
 
             # Sleep a little so we don't spam service calls
-            sleep_time = self._get_sleep_time_sec()  # type: ignore[no-untyped-call]
+            sleep_time = self._get_sleep_time_sec()
             sleep(sleep_time)
             self._total_wait_time += sleep_time
 
@@ -363,10 +369,10 @@ class ServerlessAppPlugin(BasePlugin):
                 application_ids, "Timed out waiting for nested stack templates to reach ACTIVE status."
             )
 
-    def _get_sleep_time_sec(self):  # type: ignore[no-untyped-def]
+    def _get_sleep_time_sec(self) -> int:
         return self.SLEEP_TIME_SECONDS
 
-    def _is_template_active(self, response, application_id, template_id):  # type: ignore[no-untyped-def]
+    def _is_template_active(self, response: Dict[str, Any], application_id: str, template_id: str) -> bool:
         """
         Checks the response from a SAR service call; returns True if the template is active,
         throws an exception if the request expired and returns False in all other cases.
@@ -375,10 +381,13 @@ class ServerlessAppPlugin(BasePlugin):
         :param string application_id: the ApplicationId
         :param string template_id: the unique TemplateId for this application
         """
-        status = response["Status"]  # options: PREPARING, EXPIRED or ACTIVE
+        status: str = response["Status"]  # options: PREPARING, EXPIRED or ACTIVE
 
         if status == "EXPIRED":
-            message = f"Template for {application_id} with id {template_id} returned status: {status}. Cannot access an expired template."
+            message = (
+                f"Template for {application_id} with id {template_id} returned status: {status}. "
+                "Cannot access an expired template."
+            )
             raise InvalidResourceException(application_id, message)
 
         return status == "ACTIVE"
@@ -399,7 +408,7 @@ class ServerlessAppPlugin(BasePlugin):
         except ClientError as e:
             error_code = e.response["Error"]["Code"]
             if error_code in ("AccessDeniedException", "NotFoundException"):
-                raise InvalidResourceException(logical_id, e.response["Error"]["Message"])
+                raise InvalidResourceException(logical_id, e.response["Error"]["Message"]) from e
             raise e
 
     def _resource_is_supported(self, resource_type):  # type: ignore[no-untyped-def]
