@@ -1,9 +1,9 @@
 from samtranslator.metrics.method_decorator import cw_timer
-from samtranslator.plugins import BasePlugin
-from samtranslator.model.resource_policies import ResourcePolicies, PolicyTypes
 from samtranslator.model.exceptions import InvalidResourceException
-from samtranslator.policy_template_processor.exceptions import InsufficientParameterValues, InvalidParameterValues
 from samtranslator.model.intrinsics import is_intrinsic_if, is_intrinsic_no_value
+from samtranslator.model.resource_policies import PolicyTypes, ResourcePolicies
+from samtranslator.plugins import BasePlugin
+from samtranslator.policy_template_processor.exceptions import InsufficientParameterValues, InvalidParameterValues
 
 
 class PolicyTemplatesForResourcePlugin(BasePlugin):
@@ -24,10 +24,7 @@ class PolicyTemplatesForResourcePlugin(BasePlugin):
         :param policy_template_processor: Instance of the PolicyTemplateProcessor that knows how to convert policy
             template to a statement
         """
-
-        # Plugin name is the class name for easy disambiguation
-        _plugin_name = PolicyTemplatesForResourcePlugin.__name__
-        super(PolicyTemplatesForResourcePlugin, self).__init__(_plugin_name)
+        super().__init__()
 
         self._policy_template_processor = policy_template_processor
 
@@ -39,13 +36,12 @@ class PolicyTemplatesForResourcePlugin(BasePlugin):
         :param string logical_id: Logical ID of the resource being processed
         :param string resource_type: Type of the resource being processed
         :param dict resource_properties: Properties of the resource
-        :return: Nothing
         """
 
         if not self._is_supported(resource_type):  # type: ignore[no-untyped-call]
             return
 
-        function_policies = ResourcePolicies(resource_properties, self._policy_template_processor)  # type: ignore[no-untyped-call]
+        function_policies = ResourcePolicies(resource_properties, self._policy_template_processor)
 
         if len(function_policies) == 0:
             # No policies to process
@@ -53,7 +49,6 @@ class PolicyTemplatesForResourcePlugin(BasePlugin):
 
         result = []
         for policy_entry in function_policies.get():  # type: ignore[no-untyped-call]
-
             if policy_entry.type is not PolicyTypes.POLICY_TEMPLATE:
                 # If we don't know the type, skip processing and pass to result as is.
                 result.append(policy_entry.data)
@@ -88,30 +83,24 @@ class PolicyTemplatesForResourcePlugin(BasePlugin):
             else self._process_policy_template(logical_id, else_statement)  # type: ignore[no-untyped-call]
         )
 
-        processed_intrinsic_if = {
-            "Fn::If": [policy_entry.data["Fn::If"][0], processed_then_statement, processed_else_statement]
-        }
-
-        return processed_intrinsic_if
+        return {"Fn::If": [policy_entry.data["Fn::If"][0], processed_then_statement, processed_else_statement]}
 
     def _process_policy_template(self, logical_id, template_data):  # type: ignore[no-untyped-def]
-
         # We are processing policy templates. We know they have a particular structure:
         # {"templateName": { parameter_values_dict }}
         template_name = list(template_data.keys())[0]
         template_parameters = list(template_data.values())[0]
         try:
-
             # 'convert' will return a list of policy statements
             return self._policy_template_processor.convert(template_name, template_parameters)
 
         except InsufficientParameterValues as ex:
             # Exception's message will give lot of specific details
-            raise InvalidResourceException(logical_id, str(ex))
-        except InvalidParameterValues:
+            raise InvalidResourceException(logical_id, str(ex)) from ex
+        except InvalidParameterValues as ex:
             raise InvalidResourceException(
                 logical_id, "Must specify valid parameter values for policy template '{}'".format(template_name)
-            )
+            ) from ex
 
     def _is_supported(self, resource_type):  # type: ignore[no-untyped-def]
         """
